@@ -24,24 +24,23 @@ def _load_cli(key: str) -> None:
     print(f"loaded value: '{value}'")
 
 
-def _delete_cli(key: str = None, delete_all: bool = False) -> None:
+def _delete_cli(key: str) -> None:
     """
-
-
-    :param key: A key that will be used to delete the corresponding key-value pair
-    :return: None
-
-    Deletes a key-value pair, or deletes all stored key-value pairs.
-    :param key: The key to be deleted
-    :param delete_all: If flag is true, all key-value pairs will be deleted
+    Deletes a key-value pair for the given key.
+    :param key: The key to delete the value of
     :return: None
     """
-    if delete_all:
-        _db.delete_all()
-        print(f"all key-value pairs deleted")
-    else:
-        print(f"deleted value: '{_db.read(key)}'")
-        _db.delete(key)
+    print(f"deleted value: '{_db.read(key)}'")
+    _db.delete(key)
+
+
+def _delete_all_cli() -> None:
+    """
+    Deletes all stored key-value pairs from the data.ini file.
+    :return: None
+    """
+    _db.delete_all()
+    print(f"all key-value pairs deleted")
 
 
 def _list_cli() -> None:
@@ -62,12 +61,38 @@ def _path_cli() -> None:
     print()
 
 
+def _pre_uninstall_cli() -> None:
+    """
+    Removes all persistent files and folders created by this package.
+    :return: None
+    """
+    _db.pre_uninstall()
+    print()
+    print(f"removed all persistent files and folders created by this package")
+    print(f"to uninstall this package run:")
+    print(f"pip uninstall privateprefs")
+    print()
+
+
+def _privateprefs_cli() -> None:
+    print()
+    print("Thanks for using Private Prefs!")
+    print()
+    print("for help run:")
+    print("    privateprefs -h")
+    print()
+    print("or visit:")
+    print("    https://github.com/DarrenHaba/privateprefs#readme")
+    print()
+
+
 def print_key_value_table() -> None:
     """
     Prints out a table of all saved key-value pairs.
     :return: None
     """
     print()
+    print(f"key-value pairs in: {_db.PATH_TO_DATA_FILE}")
     key_value_pairs = _db.read_keys()
 
     if len(key_value_pairs) > 0:
@@ -117,6 +142,10 @@ def main(argv=None) -> None:
 
     # To make argparse sub-parsers easier to deal with, we set up one function per subparsers.
 
+    # The List sub-parsers.
+    # A function called '__cli' will be dynamically called when the '' command is invoked
+    subparsers.add_parser("")
+
     # The Save sub-parsers.
     # A function called '_save_cli' will be dynamically called when the 'save' command is invoked
     parser_save = subparsers.add_parser("save")
@@ -138,21 +167,16 @@ def main(argv=None) -> None:
 
     # The Delete sub-parsers.
     # A function called 'delete_' will be dynamically called when the 'delete' command is invoked
-    # Note that only the 'key' or '--all' argument is required, depending on if we want to delete
-    # single key-value pair or all key-value pairs.
     parser_delete = subparsers.add_parser("delete")
-    parser_delete.add_argument('key', nargs='?')
-    parser_delete.add_argument("--all",
-                               dest="delete_all",
-                               action="store_true")
-    args = parser.parse_args(argv)
-    no_args_given = args.subparser == "delete" and args.key is None and args.delete_all is False
-    if no_args_given:
-        print()
-        raise parser.error("\nplease enter a key string argument e.g.:\n"
-                           "privateprefs delete 'my key'\n"
-                           "or to delete all key-value pairs use the '--all' flag e.g.\n"
-                           "privateprefs delete --all\n")
+    parser_delete.add_argument("key")
+
+    # The Path sub-parsers.
+    # A function called '_delete_all_cli' will be dynamically called when the 'delete_all' command is invoked
+    subparsers.add_parser("delete_all")
+
+    # The Path sub-parsers.
+    # A function called '_pre_uninstall_cli' will be dynamically called when the 'pre_uninstall' command is invoked
+    subparsers.add_parser("pre_uninstall")
 
     # Extract a dict containing the name of the sub processor invoked and its arguments
     kwargs = vars(parser.parse_args(argv))
@@ -161,9 +185,14 @@ def main(argv=None) -> None:
     # so now kwargs will be just the given arguments without the subcommand in the dict.
     func_name_to_call = kwargs.pop('subparser')  # will be: save, load, delete, etc.
 
-    # The private cli functions start with an underscore and end with _cli, so we append it here.
-    # E.g. if we called 'save' in the cli, here it would become '_save_cli' to match the function name.
-    func_name_to_call = f"_{func_name_to_call}_cli"
+    if func_name_to_call is None:
+        #  'privateprefs' was called.
+        func_name_to_call = "_privateprefs_cli"
+    else:
+        # A subcommand was called
+        # Make the command name match the corresponding function
+        # CLI functions start with an underscore and end with _cli, so we append it here.
+        func_name_to_call = f"_{func_name_to_call}_cli"
 
     # We dynamically call the function from the globals namespace dictionary and pass in cli the arguments.
     globals()[func_name_to_call](**kwargs)
